#!/usr/bin/env bash

# cp.sh - copy files to new location.
# Copyright (c) 2022 ge <https://nixhacks.net/>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

handler::cp() {
    # Transfer files to another location from __main_target_path using cp(1)
    # Handle 'file' URI scheme.
    #
    # Usage: handler::cp URI

    log "Run handler handler::cp()"

    local uri
    local dst_path

    uri="$1"

    # shellcheck disable=SC2154
    if [[ "$uri" == "$__main_target" ]]; then
        : # Do nothing. Source and destination is the same
        log "Nothing to do: Source and destination is the same: $__main_target"
    else
        # Copy backups to another destination
        parse_uri "$uri"

        # shellcheck disable=SC2154
        if [ -f "$path" ] || [ -d "$path" ]; then
            dst_path="$path"
        else
            echo "Error: Path '$path' from URI '$uri' does not exists" >&2
            exit 1
        fi

        [ "$__verbose" ] && echo "Destination path: $dst_path"

        # Copy files preserving metadata
        # shellcheck disable=SC2154
        for backup in "${backups[@]}"; do
            log "Copying file $backup to $dst_path ..."
            log "Run command: cp --archive $backup $dst_path"
            [ "$__verbose" ] && echo "Run command: cp --archive $backup $dst_path"
            try cp --archive "$backup" "$dst_path"
        done
    fi
}
